summaryrefslogtreecommitdiffstats
path: root/chrome/browser/tab_contents
diff options
context:
space:
mode:
authorjhawkins@chromium.org <jhawkins@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-02 19:55:45 +0000
committerjhawkins@chromium.org <jhawkins@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-02 19:55:45 +0000
commit6db0def9b89c58b9ade972ac1e9b0d4f8f88d858 (patch)
treed9e0a78de0fd72ec56e424750f3b399e89010f70 /chrome/browser/tab_contents
parent7fce6e9a1e243fe31b686ef2123c453f7f210450 (diff)
downloadchromium_src-6db0def9b89c58b9ade972ac1e9b0d4f8f88d858.zip
chromium_src-6db0def9b89c58b9ade972ac1e9b0d4f8f88d858.tar.gz
chromium_src-6db0def9b89c58b9ade972ac1e9b0d4f8f88d858.tar.bz2
Rename FormFieldHistoryManager to AutocompleteHistory manager to better reflect its relation to the Autocomplete feature.
BUG=33032 TEST=none Review URL: http://codereview.chromium.org/661323 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@40408 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/tab_contents')
-rw-r--r--chrome/browser/tab_contents/tab_contents.cc10
-rw-r--r--chrome/browser/tab_contents/tab_contents.h6
2 files changed, 8 insertions, 8 deletions
diff --git a/chrome/browser/tab_contents/tab_contents.cc b/chrome/browser/tab_contents/tab_contents.cc
index 205b56d..254567c 100644
--- a/chrome/browser/tab_contents/tab_contents.cc
+++ b/chrome/browser/tab_contents/tab_contents.cc
@@ -13,6 +13,7 @@
#include "base/string16.h"
#include "base/string_util.h"
#include "base/time.h"
+#include "chrome/browser/autocomplete_history_manager.h"
#include "chrome/browser/autofill/autofill_manager.h"
#include "chrome/browser/blocked_popup_container.h"
#include "chrome/browser/bookmarks/bookmark_model.h"
@@ -30,7 +31,6 @@
#include "chrome/browser/external_protocol_handler.h"
#include "chrome/browser/extensions/extensions_service.h"
#include "chrome/browser/favicon_service.h"
-#include "chrome/browser/form_field_history_manager.h"
#include "chrome/browser/google_util.h"
#include "chrome/browser/host_content_settings_map.h"
#include "chrome/browser/hung_renderer_dialog.h"
@@ -237,7 +237,7 @@ TabContents::TabContents(Profile* profile,
registrar_(),
ALLOW_THIS_IN_INITIALIZER_LIST(printing_(*this)),
save_package_(),
- form_field_history_manager_(),
+ autocomplete_history_manager_(),
autofill_manager_(),
password_manager_(),
plugin_installer_(),
@@ -2035,9 +2035,9 @@ RenderViewHostDelegate::FavIcon* TabContents::GetFavIconDelegate() {
RenderViewHostDelegate::FormFieldHistory*
TabContents::GetFormFieldHistoryDelegate() {
- if (form_field_history_manager_.get() == NULL)
- form_field_history_manager_.reset(new FormFieldHistoryManager(this));
- return form_field_history_manager_.get();
+ if (autocomplete_history_manager_.get() == NULL)
+ autocomplete_history_manager_.reset(new AutocompleteHistoryManager(this));
+ return autocomplete_history_manager_.get();
}
RenderViewHostDelegate::AutoFill* TabContents::GetAutoFillDelegate() {
diff --git a/chrome/browser/tab_contents/tab_contents.h b/chrome/browser/tab_contents/tab_contents.h
index 6df01f0..1fae555 100644
--- a/chrome/browser/tab_contents/tab_contents.h
+++ b/chrome/browser/tab_contents/tab_contents.h
@@ -69,7 +69,7 @@ class BlockedPopupContainer;
class DOMUI;
class DownloadItem;
class Extension;
-class FormFieldHistoryManager;
+class AutocompleteHistoryManager;
class LoadNotificationDetails;
class OmniboxSearchHint;
class PasswordManager;
@@ -993,8 +993,8 @@ class TabContents : public PageNavigator,
// SavePackage, lazily created.
scoped_refptr<SavePackage> save_package_;
- // FormFieldHistoryManager, lazily created.
- scoped_ptr<FormFieldHistoryManager> form_field_history_manager_;
+ // AutocompleteHistoryManager, lazily created.
+ scoped_ptr<AutocompleteHistoryManager> autocomplete_history_manager_;
// AutoFillManager, lazily created.
scoped_ptr<AutoFillManager> autofill_manager_;